# We can change the skill list to each profession
skills_list = [
            'Python', 'Data Analysis', 'Machine Learning', 'Communication', 'Project Management', 'Deep Learning',
            'SQL', 'Tableau', 'NLP', 'Computer Vision', 'OpenCV', 'Pyresparser', 'Roberta', 'Spacy',
            'Scikit-Learn', 'Scipy', 'Neural Network', 'Docker', 'Jenkins', 'Github', 'AWS', 'Azure',
            'GCP', 'BERT', 'Data Scientist', 'ROBOT', 'MySQL', 'AI-Artificial Intelligence', 'Research & Development',
            'Pattern Recognition', 'Problem Solving', 'Debugging', 'Troubleshooting', 'Monitoring', 'Unit Testing',
            'Testing', 'Visualization', 'Software Developement', 'Robotics', 'Raspberry Pi', 'Sentimental Analysis',
            'DecisionMaking', 'Dlib', 'HOG', 'Javascript', 'HTML', 'CSS', 'React', 'Typescript', 
        ]

# We can change the designation list to each profession
designations_list = ['Consultant', 'Software Developer', 'Assistant Systems Engineer',"Software", "Engineer", "Consultant", "Assistant", "Manager",
    "Developer", "Intern", "Architect", "Lead", "Executive", "Customer Service Executive"
]

company_suffixes = [
    "Solutions", "Services", "Consultancy", "Labs", "Systems",
    "Corporation", "Company", "Inc", "Limited", "Ltd", "LLP", "LLC",
    "Pvt", "Pvt. Ltd", "Private Limited", "IT Services", "SaaS", "Group"
]